==> libcamera-docs-0.0.3-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_16.js <==
var searchData=
[
  ['v4l2buffercache_0',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)'],['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)']]],
  ['v4l2device_1',['V4L2Device',['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device']]],
  ['v4l2m2mconverter_2',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter']]],
  ['v4l2m2mdevice_3',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice']]],
  ['v4l2pixelformat_4',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_5',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice']]],
  ['v4l2videodevice_6',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)'],['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)']]],
  ['validate_7',['validate',['../classlibcamera_1_1CameraConfiguration.html#a29f8f263384c6149775b6011c7397093',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#abcdc9ac8a5bb8d5342d2fb7fb1ce51f5',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_8',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validator_9',['validator',['../classlibcamera_1_1Camera_1_1Private.html#ab3b02eaffac28effb9752c332318062b',1,'libcamera::Camera::Private']]],
  ['values_10',['values',['../classlibcamera_1_1ControlInfo.html#a51aa2edf48c4ee436f5eebbcd2efe960',1,'libcamera::ControlInfo']]],
  ['verify_11',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_12',['version',['../classlibcamera_1_1CameraManager.html#a491b49c074dfc3c55e791b2b63437011',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#afd096dd0104ddc8737f56cf23e28d8d6',1,'libcamera::MediaDevice::version()']]]
];

==> libcamera-docs-0.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_16.js <==
var searchData=
[
  ['v4l2buffercache_0',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)']]],
  ['v4l2device_1',['V4L2Device',['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device']]],
  ['v4l2m2mconverter_2',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter']]],
  ['v4l2m2mdevice_3',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice']]],
  ['v4l2pixelformat_4',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_5',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice']]],
  ['v4l2videodevice_6',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)']]],
  ['validate_7',['validate',['../classlibcamera_1_1CameraConfiguration.html#a29f8f263384c6149775b6011c7397093',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#abcdc9ac8a5bb8d5342d2fb7fb1ce51f5',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_8',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validator_9',['validator',['../classlibcamera_1_1Camera_1_1Private.html#ab3b02eaffac28effb9752c332318062b',1,'libcamera::Camera::Private']]],
  ['values_10',['values',['../classlibcamera_1_1ControlInfo.html#a51aa2edf48c4ee436f5eebbcd2efe960',1,'libcamera::ControlInfo']]],
  ['verify_11',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_12',['version',['../classlibcamera_1_1CameraManager.html#a491b49c074dfc3c55e791b2b63437011',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#afd096dd0104ddc8737f56cf23e28d8d6',1,'libcamera::MediaDevice::version()']]]
];
